==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/kubernetes/api/model/ResourceQuotaSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ResourceQuotaSpecFluentImpl<T extends ResourceQuotaSpecFluent<T>> extends BaseFluent<T> implements ResourceQuotaSpecFluent<T>{

     Map<String, Quantity> hard = new HashMap();     Map<String, Object> additionalProperties = new HashMap();

    public T addToHard( String key,  Quantity value){
    if(key != null && value != null) {this.hard.put(key, value);} return (T)this;
    }
    public T addToHard( Map<String, Quantity> map){
    if(map != null) { this.hard.putAll(map);} return (T)this;
    }
    public T removeFromHard( String key){
    if(key != null) {this.hard.remove(key);} return (T)this;
    }
    public T removeFromHard( Map<String, Quantity> map){
    if(map != null) { for(Object key : map.keySet()) {this.hard.remove(key);}} return (T)this;
    }
    public Map<String, Quantity> getHard(){
    return this.hard;
    }
    public T withHard( Map<String, Quantity> hard){
    this.hard.clear();if (hard != null) {this.hard.putAll(hard);} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ResourceQuotaSpecFluentImpl that = (ResourceQuotaSpecFluentImpl) o;
if (hard != null ? !hard.equals(that.hard) :that.hard != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.36-sources.jar: annotations/io/fabric8/kubernetes/api/model/ResourceQuotaSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ResourceQuotaSpecFluentImpl<T extends ResourceQuotaSpecFluent<T>> extends BaseFluent<T> implements ResourceQuotaSpecFluent<T>{

     Map<String, Quantity> hard = new HashMap();     Map<String, Object> additionalProperties = new HashMap();
public ResourceQuotaSpecFluentImpl(){
    
}
public ResourceQuotaSpecFluentImpl( ResourceQuotaSpec instance ){
    this.withHard(instance.getHard()); 
}

    public T addToHard( String key,  Quantity value){
    if(key != null && value != null) {this.hard.put(key, value);} return (T)this;
    }
    public T addToHard( Map<String, Quantity> map){
    if(map != null) { this.hard.putAll(map);} return (T)this;
    }
    public T removeFromHard( String key){
    if(key != null) {this.hard.remove(key);} return (T)this;
    }
    public T removeFromHard( Map<String, Quantity> map){
    if(map != null) { for(Object key : map.keySet()) {this.hard.remove(key);}} return (T)this;
    }
    public Map<String, Quantity> getHard(){
    return this.hard;
    }
    public T withHard( Map<String, Quantity> hard){
    this.hard.clear();if (hard != null) {this.hard.putAll(hard);} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ResourceQuotaSpecFluentImpl that = (ResourceQuotaSpecFluentImpl) o;
if (hard != null ? !hard.equals(that.hard) :that.hard != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
